@@ -70,13 +70,14 @@ func TestBucketsCreate(t *testing.T) {
 				bucketsApi.EXPECT().
 					PostBucketsExecute(tmock.MatchedBy(func(in api.ApiPostBucketsRequest) bool {
 						body := in.GetPostBucketRequest()
+						retentionRules := *body.RetentionRules
 						return assert.NotNil(t, body) &&
 							assert.Equal(t, "123", body.OrgID) &&
 							assert.Equal(t, "my-bucket", body.Name) &&
 							assert.Equal(t, "my cool bucket", *body.Description) &&
-							assert.Len(t, body.RetentionRules, 1) &&
-							assert.Equal(t, int64(86400), body.RetentionRules[0].EverySeconds) &&
-							assert.Equal(t, int64(3600), *body.RetentionRules[0].ShardGroupDurationSeconds)
+							assert.Len(t, retentionRules, 1) &&
+							assert.Equal(t, int64(86400), retentionRules[0].EverySeconds) &&
+							assert.Equal(t, int64(3600), *retentionRules[0].ShardGroupDurationSeconds)
 					})).
 					Return(api.Bucket{
 						Id:    api.PtrString("456"),
@@ -101,13 +102,14 @@ func TestBucketsCreate(t *testing.T) {
 				bucketsApi.EXPECT().
 					PostBucketsExecute(tmock.MatchedBy(func(in api.ApiPostBucketsRequest) bool {
 						body := in.GetPostBucketRequest()
+						retentionRules := *body.RetentionRules
 						return assert.NotNil(t, body) &&
 							assert.Equal(t, "123", body.OrgID) &&
 							assert.Equal(t, "my-bucket", body.Name) &&
 							assert.Nil(t, body.Description) &&
-							assert.Len(t, body.RetentionRules, 1) &&
-							assert.Equal(t, int64(86400), body.RetentionRules[0].EverySeconds) &&
-							assert.Nil(t, body.RetentionRules[0].ShardGroupDurationSeconds)
+							assert.Len(t, *body.RetentionRules, 1) &&
+							assert.Equal(t, int64(86400), retentionRules[0].EverySeconds) &&
+							assert.Nil(t, retentionRules[0].ShardGroupDurationSeconds)
 					})).
 					Return(api.Bucket{
 						Id:             api.PtrString("456"),
@@ -168,13 +170,14 @@ func TestBucketsCreate(t *testing.T) {
 				bucketsApi.EXPECT().
 					PostBucketsExecute(tmock.MatchedBy(func(in api.ApiPostBucketsRequest) bool {
 						body := in.GetPostBucketRequest()
+						retentionRules := *body.RetentionRules
 						return assert.NotNil(t, body) &&
 							assert.Equal(t, "123", body.OrgID) &&
 							assert.Equal(t, "my-bucket", body.Name) &&
 							assert.Equal(t, "my cool bucket", *body.Description) &&
-							assert.Len(t, body.RetentionRules, 1) &&
-							assert.Equal(t, int64(86400), body.RetentionRules[0].EverySeconds) &&
-							assert.Equal(t, int64(3600), *body.RetentionRules[0].ShardGroupDurationSeconds)
+							assert.Len(t, *body.RetentionRules, 1) &&
+							assert.Equal(t, int64(86400), retentionRules[0].EverySeconds) &&
+							assert.Equal(t, int64(3600), *retentionRules[0].ShardGroupDurationSeconds)
 					})).
 					Return(api.Bucket{
 						Id:    api.PtrString("456"),
@@ -210,13 +213,14 @@ func TestBucketsCreate(t *testing.T) {
 				bucketsApi.EXPECT().
 					PostBucketsExecute(tmock.MatchedBy(func(in api.ApiPostBucketsRequest) bool {
 						body := in.GetPostBucketRequest()
+						retentionRules := *body.RetentionRules
 						return assert.NotNil(t, body) &&
 							assert.Equal(t, "123", body.OrgID) &&
 							assert.Equal(t, "my-bucket", body.Name) &&
 							assert.Equal(t, "my cool bucket", *body.Description) &&
-							assert.Len(t, body.RetentionRules, 1) &&
-							assert.Equal(t, int64(86400), body.RetentionRules[0].EverySeconds) &&
-							assert.Equal(t, int64(3600), *body.RetentionRules[0].ShardGroupDurationSeconds)
+							assert.Len(t, *body.RetentionRules, 1) &&
+							assert.Equal(t, int64(86400), retentionRules[0].EverySeconds) &&
+							assert.Equal(t, int64(3600), *retentionRules[0].ShardGroupDurationSeconds)
 					})).
 					Return(api.Bucket{
 						Id:    api.PtrString("456"),
