@@ -19,7 +19,12 @@ type Client struct {
 
 type CreateParams struct {
 	clients.OrgParams
-	FluxQuery string
+	FluxQuery    string
+	Name         string
+	Every        string
+	Cron         string
+	ScriptID     string
+	ScriptParams map[string]interface{}
 }
 
 type NameOrID struct {
@@ -72,11 +77,32 @@ func (c Client) Create(ctx context.Context, params *CreateParams) error {
 	if err != nil {
 		return err
 	}
-	createRequest := api.TaskCreateRequest{
-		Flux:  params.FluxQuery,
-		OrgID: org.IDOrNil(),
-		Org:   org.NameOrNil(),
+
+	scriptID := &params.ScriptID
+	if len(params.ScriptID) == 0 {
+		scriptID = nil
 	}
+
+	scriptParams := &params.ScriptParams
+	if len(params.ScriptParams) == 0 {
+		scriptParams = nil
+	}
+
+	createRequest := api.TaskCreateRequest{
+		Flux:             &params.FluxQuery,
+		OrgID:            org.IDOrNil(),
+		Org:              org.NameOrNil(),
+		Name:             &params.Name,
+		Cron:             &params.Cron,
+		ScriptID:         scriptID,
+		ScriptParameters: scriptParams,
+	}
+
+	// The FluxQuery can also contain the "every" field, so we only want to override if it is actually defined.
+	if params.Every != "" {
+		createRequest.Every = &params.Every
+	}
+
 	task, err := c.PostTasks(ctx).TaskCreateRequest(createRequest).Execute()
 	if err != nil {
 		return err
@@ -88,9 +114,10 @@ func (c Client) Create(ctx context.Context, params *CreateParams) error {
 
 type FindParams struct {
 	clients.OrgParams
-	TaskID string
-	UserID string
-	Limit  int
+	TaskID   string
+	UserID   string
+	ScriptID string
+	Limit    int
 }
 
 func (c Client) Find(ctx context.Context, params *FindParams) error {
@@ -120,6 +147,9 @@ func (c Client) Find(ctx context.Context, params *FindParams) error {
 		if params.UserID != "" {
 			getTask = getTask.User(params.UserID)
 		}
+		if params.ScriptID != "" {
+			getTask = getTask.ScriptID(params.ScriptID)
+		}
 		tasksResult, err := getTask.Execute()
 		if err != nil {
 			return err
@@ -258,9 +288,11 @@ Rerun without '--dry-run' to execute
 }
 
 type UpdateParams struct {
-	FluxQuery string
-	TaskID    string
-	Status    string
+	FluxQuery    string
+	TaskID       string
+	Status       string
+	ScriptID     string
+	ScriptParams map[string]interface{}
 }
 
 func (c Client) Update(ctx context.Context, params *UpdateParams) error {
@@ -277,9 +309,22 @@ func (c Client) Update(ctx context.Context, params *UpdateParams) error {
 		}
 		status = &s
 	}
+
+	scriptID := &params.ScriptID
+	if len(params.ScriptID) == 0 {
+		scriptID = nil
+	}
+
+	scriptParams := &params.ScriptParams
+	if len(params.ScriptParams) == 0 {
+		scriptParams = nil
+	}
+
 	task, err := c.PatchTasksID(ctx, params.TaskID).TaskUpdateRequest(api.TaskUpdateRequest{
-		Status: status,
-		Flux:   flux,
+		Status:           status,
+		Flux:             flux,
+		ScriptID:         scriptID,
+		ScriptParameters: scriptParams,
 	}).Execute()
 	if err != nil {
 		return err
@@ -336,6 +381,7 @@ func (c Client) printTasks(printOpts taskPrintOpts) error {
 		"Status",
 		"Every",
 		"Cron",
+		"ScriptID",
 	}
 
 	if printOpts.task != nil {
@@ -352,6 +398,7 @@ func (c Client) printTasks(printOpts taskPrintOpts) error {
 			"Status":          derefOrEmpty((*string)(t.Status)),
 			"Every":           derefOrEmpty(t.Every),
 			"Cron":            derefOrEmpty(t.Cron),
+			"ScriptID":        derefOrEmpty(t.ScriptID),
 		}
 		rows = append(rows, row)
 	}
